==> bioinformagic_messages-0.1.tar.gz: bioinformagic_messages-0.1/setup.py <==
from distutils.core import setup
setup(
  name = 'bioinformagic_messages',         # How you named your package folder (MyLib)
  packages = ['bioinformagic_messages'],   # Chose the same as "name"
  version = '0.1',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'Randomly generate completely useless bioinformatics-related loading messages',   # Give a short description about your library
  author = 'Joseph Mahon',                   # Type in your name
  author_email = 'joemahon89@gmail.com',      # Type in your E-Mail
  url = 'https://github.com/joemahon89/bioinformagic_messages',   # Provide either the link to your github or to your website
  download_url = 'https://github.com/joemahon89/bioinformagic_messages/archive/v_01.tar.gz',    # I explain this later on
  keywords = ['bioinformatics', 'random', 'messages'],   # Keywords that define your package best
  install_requires=[],
  classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package    
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Scientific/Engineering :: Bio-Informatics',
    'License :: OSI Approved :: MIT License',   # Again, pick a license    
    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
    'Programming Language :: Python :: 3.7',
  ],
)

==> bioinformagic_messages-0.1.1.tar.gz: bioinformagic_messages-0.1.1/setup.py <==
import os
from setuptools import setup

def read(fname):
    return open(os.path.join(os.path.dirname(__file__), fname)).read()

setup(
  name = 'bioinformagic_messages',         # How you named your package folder (MyLib)
  packages = ['bioinformagic_messages'],   # Chose the same as "name"
  version = '0.1.1',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'Randomly generate completely useless bioinformatics-related loading messages',   # Give a short description about your library
  author = 'Joseph Mahon',                   # Type in your name
  author_email = 'joemahon89@gmail.com',      # Type in your E-Mail
  url = 'https://github.com/joemahon89/bioinformagic_messages',   # Provide either the link to your github or to your website
  download_url = 'https://github.com/joemahon89/bioinformagic_messages/archive/v_01.1.tar.gz',    # I explain this later on
  long_description=read('README'),
  long_description_content_type='text/markdown',
  keywords = ['bioinformatics', 'random', 'messages'],   # Keywords that define your package best
  install_requires=[],
  classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package    
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Scientific/Engineering :: Bio-Informatics',
    'License :: OSI Approved :: MIT License',   # Again, pick a license    
    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
    'Programming Language :: Python :: 3.7',
  ],
)
